@@ -16,7 +16,8 @@ function(behavior,phaseX,v1){
   BetaA<-regA$coefficient[2]
   
   
-  graphics.off()
+  #graphics.off()
+  layout(rbind(1,2), heights=c(4,1))
   plot(x1, A,lwd=2,type="o",col="red", xlab="time", ylab="behavior", main=v1 )
   abline(c(yA,BetaA),col='Blue',lty="dashed")
   print(summary(regA))
